==> ejc-analysis-impl-3.0.0-20230630.095827-36-sources.jar: com/ejianc/business/analysis/bean/ProSignReserveEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目责任书签订及风险金预留情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_analysis_project_sign_reserve")
public class ProSignReserveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="project_status")
    private Long projectStatus; // 项目状态
    @TableField(value="contract_sign_time")
    private Date contractSignTime; // 合同签订时间
    @TableField(value="contract_amount")
    private BigDecimal contractAmount; // 合同额(万元)
    @TableField(value="ac_contract_amount")
    private BigDecimal acContractAmount; // 自施合同额(万元)
    @TableField(value="responsibility_cost")
    private BigDecimal responsibilityCost; // 责任成本(万元)
    @TableField(value="undertaking_benefits")
    private BigDecimal undertakingBenefits; // 承接效益
    @TableField(value="undertaking_benefits_rate")
    private BigDecimal undertakingBenefitsRate; // 承接效益率
    @TableField(value="overall_profit_margin")
    private BigDecimal overallProfitMargin; // 整体上缴利润率
    @TableField(value="trs_reserved_amount")
    private BigDecimal trsReservedAmount; // 目标责任书应预留金额(万元)
    @TableField(value="approved_reserved_amount")
    private BigDecimal approvedReservedAmount; // 核定应预留金额(万元)
    @TableField(value="actual_reserved_amount")
    private BigDecimal actualReservedAmount; // 实际预留金额(万元)
    @TableField(value="risk_reserve")
    private BigDecimal riskReserve; // 风险金预留%
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getContractSignTime() {
        return contractSignTime;
    }

    public void setContractSignTime(Date contractSignTime) {
        this.contractSignTime = contractSignTime;
    }
    public BigDecimal getContractAmount() {
        return contractAmount;
    }

    public void setContractAmount(BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    public BigDecimal getAcContractAmount() {
        return acContractAmount;
    }

    public void setAcContractAmount(BigDecimal acContractAmount) {
        this.acContractAmount = acContractAmount;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getUndertakingBenefits() {
        return undertakingBenefits;
    }

    public void setUndertakingBenefits(BigDecimal undertakingBenefits) {
        this.undertakingBenefits = undertakingBenefits;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public BigDecimal getTrsReservedAmount() {
        return trsReservedAmount;
    }

    public void setTrsReservedAmount(BigDecimal trsReservedAmount) {
        this.trsReservedAmount = trsReservedAmount;
    }
    public BigDecimal getApprovedReservedAmount() {
        return approvedReservedAmount;
    }

    public void setApprovedReservedAmount(BigDecimal approvedReservedAmount) {
        this.approvedReservedAmount = approvedReservedAmount;
    }
    public BigDecimal getActualReservedAmount() {
        return actualReservedAmount;
    }

    public void setActualReservedAmount(BigDecimal actualReservedAmount) {
        this.actualReservedAmount = actualReservedAmount;
    }
    public BigDecimal getRiskReserve() {
        return riskReserve;
    }

    public void setRiskReserve(BigDecimal riskReserve) {
        this.riskReserve = riskReserve;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    
}

==> ejc-analysis-impl-3.0.0-20230711.032208-47-sources.jar: com/ejianc/business/analysis/bean/ProSignReserveEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目责任书签订及风险金预留情况
 *
 * @author generator
 *
 */
 @TableName("ejc_analysis_project_sign_reserve")
public class ProSignReserveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="project_status")
    private Long projectStatus; // 项目状态
    @TableField(value="contract_sign_time")
    private Date contractSignTime; // 合同签订时间
    @TableField(value="contract_amount")
    private BigDecimal contractAmount; // 合同额(万元)
    @TableField(value="ac_contract_amount")
    private BigDecimal acContractAmount; // 自施合同额(万元)
    @TableField(value="responsibility_cost")
    private BigDecimal responsibilityCost; // 责任成本(万元)
    @TableField(value="undertaking_benefits")
    private BigDecimal undertakingBenefits; // 承接效益
    @TableField(value="undertaking_benefits_rate")
    private BigDecimal undertakingBenefitsRate; // 承接效益率
    @TableField(value="overall_profit_margin")
    private BigDecimal overallProfitMargin; // 整体上缴利润率
    @TableField(value="trs_reserved_amount")
    private BigDecimal trsReservedAmount; // 目标责任书应预留金额(万元)
    @TableField(value="approved_reserved_amount")
    private BigDecimal approvedReservedAmount; // 核定应预留金额(万元)
    @TableField(value="actual_reserved_amount")
    private BigDecimal actualReservedAmount; // 实际预留金额(万元)
    @TableField(value="risk_reserve")
    private BigDecimal riskReserve; // 风险金预留%
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="book_sign_time")
    private Date bookSignTime; // 责任书签订时间
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期



    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getContractSignTime() {
        return contractSignTime;
    }

    public void setContractSignTime(Date contractSignTime) {
        this.contractSignTime = contractSignTime;
    }
    public BigDecimal getContractAmount() {
        return contractAmount;
    }

    public void setContractAmount(BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    public BigDecimal getAcContractAmount() {
        return acContractAmount;
    }

    public void setAcContractAmount(BigDecimal acContractAmount) {
        this.acContractAmount = acContractAmount;
    }
    public BigDecimal getResponsibilityCost() {
        return responsibilityCost;
    }

    public void setResponsibilityCost(BigDecimal responsibilityCost) {
        this.responsibilityCost = responsibilityCost;
    }
    public BigDecimal getUndertakingBenefits() {
        return undertakingBenefits;
    }

    public void setUndertakingBenefits(BigDecimal undertakingBenefits) {
        this.undertakingBenefits = undertakingBenefits;
    }
    public BigDecimal getUndertakingBenefitsRate() {
        return undertakingBenefitsRate;
    }

    public void setUndertakingBenefitsRate(BigDecimal undertakingBenefitsRate) {
        this.undertakingBenefitsRate = undertakingBenefitsRate;
    }
    public BigDecimal getOverallProfitMargin() {
        return overallProfitMargin;
    }

    public void setOverallProfitMargin(BigDecimal overallProfitMargin) {
        this.overallProfitMargin = overallProfitMargin;
    }
    public BigDecimal getTrsReservedAmount() {
        return trsReservedAmount;
    }

    public void setTrsReservedAmount(BigDecimal trsReservedAmount) {
        this.trsReservedAmount = trsReservedAmount;
    }
    public BigDecimal getApprovedReservedAmount() {
        return approvedReservedAmount;
    }

    public void setApprovedReservedAmount(BigDecimal approvedReservedAmount) {
        this.approvedReservedAmount = approvedReservedAmount;
    }
    public BigDecimal getActualReservedAmount() {
        return actualReservedAmount;
    }

    public void setActualReservedAmount(BigDecimal actualReservedAmount) {
        this.actualReservedAmount = actualReservedAmount;
    }
    public BigDecimal getRiskReserve() {
        return riskReserve;
    }

    public void setRiskReserve(BigDecimal riskReserve) {
        this.riskReserve = riskReserve;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public Date getBookSignTime() {
        return bookSignTime;
    }

    public void setBookSignTime(Date bookSignTime) {
        this.bookSignTime = bookSignTime;
    }

    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
}
